pykeen.models.base.EntityRelationEmbeddingModel
===============================================

.. currentmodule:: pykeen.models.base

.. autoclass:: EntityRelationEmbeddingModel

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EntityRelationEmbeddingModel.__init__
      ~EntityRelationEmbeddingModel.add_module
      ~EntityRelationEmbeddingModel.apply
      ~EntityRelationEmbeddingModel.bfloat16
      ~EntityRelationEmbeddingModel.buffers
      ~EntityRelationEmbeddingModel.children
      ~EntityRelationEmbeddingModel.compute_label_loss
      ~EntityRelationEmbeddingModel.compute_mr_loss
      ~EntityRelationEmbeddingModel.compute_self_adversarial_negative_sampling_loss
      ~EntityRelationEmbeddingModel.cpu
      ~EntityRelationEmbeddingModel.cuda
      ~EntityRelationEmbeddingModel.double
      ~EntityRelationEmbeddingModel.eval
      ~EntityRelationEmbeddingModel.extra_repr
      ~EntityRelationEmbeddingModel.float
      ~EntityRelationEmbeddingModel.forward
      ~EntityRelationEmbeddingModel.get_grad_params
      ~EntityRelationEmbeddingModel.half
      ~EntityRelationEmbeddingModel.load_state
      ~EntityRelationEmbeddingModel.load_state_dict
      ~EntityRelationEmbeddingModel.modules
      ~EntityRelationEmbeddingModel.named_buffers
      ~EntityRelationEmbeddingModel.named_children
      ~EntityRelationEmbeddingModel.named_modules
      ~EntityRelationEmbeddingModel.named_parameters
      ~EntityRelationEmbeddingModel.parameters
      ~EntityRelationEmbeddingModel.post_parameter_update
      ~EntityRelationEmbeddingModel.predict_heads
      ~EntityRelationEmbeddingModel.predict_scores
      ~EntityRelationEmbeddingModel.predict_scores_all_heads
      ~EntityRelationEmbeddingModel.predict_scores_all_relations
      ~EntityRelationEmbeddingModel.predict_scores_all_tails
      ~EntityRelationEmbeddingModel.predict_tails
      ~EntityRelationEmbeddingModel.register_backward_hook
      ~EntityRelationEmbeddingModel.register_buffer
      ~EntityRelationEmbeddingModel.register_forward_hook
      ~EntityRelationEmbeddingModel.register_forward_pre_hook
      ~EntityRelationEmbeddingModel.register_parameter
      ~EntityRelationEmbeddingModel.regularize_if_necessary
      ~EntityRelationEmbeddingModel.requires_grad_
      ~EntityRelationEmbeddingModel.reset_parameters_
      ~EntityRelationEmbeddingModel.save_state
      ~EntityRelationEmbeddingModel.score_h
      ~EntityRelationEmbeddingModel.score_hrt
      ~EntityRelationEmbeddingModel.score_r
      ~EntityRelationEmbeddingModel.score_t
      ~EntityRelationEmbeddingModel.share_memory
      ~EntityRelationEmbeddingModel.state_dict
      ~EntityRelationEmbeddingModel.to
      ~EntityRelationEmbeddingModel.to_cpu_
      ~EntityRelationEmbeddingModel.to_device_
      ~EntityRelationEmbeddingModel.to_embeddingdb
      ~EntityRelationEmbeddingModel.to_gpu_
      ~EntityRelationEmbeddingModel.train
      ~EntityRelationEmbeddingModel.type
      ~EntityRelationEmbeddingModel.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~EntityRelationEmbeddingModel.can_slice_h
      ~EntityRelationEmbeddingModel.can_slice_r
      ~EntityRelationEmbeddingModel.can_slice_t
      ~EntityRelationEmbeddingModel.dump_patches
      ~EntityRelationEmbeddingModel.loss_default_kwargs
      ~EntityRelationEmbeddingModel.modules_not_supporting_sub_batching
      ~EntityRelationEmbeddingModel.num_entities
      ~EntityRelationEmbeddingModel.num_parameter_bytes
      ~EntityRelationEmbeddingModel.num_relations
      ~EntityRelationEmbeddingModel.regularizer_default_kwargs
      ~EntityRelationEmbeddingModel.supports_subbatching
   
   